#ifndef POLICYTYPE_H
#define POLICYTYPE_H

#include <QtGlobal>

/*!
  \namespace Sailfish::PolicyTypes
  \internal
*/

#ifdef  __cplusplus
namespace Sailfish {
namespace PolicyTypes {
#endif

enum PolicyType {
    Unknown,
    CameraEnabled,
    LocationSettingsEnabled,
    OsUpdatesEnabled,
    SideLoadingSettingsEnabled Q_DECL_DEPRECATED,
    DeveloperModeSettingsEnabled,
    ApplicationInstallationEnabled,
    WlanToggleEnabled,
    InternetSharingEnabled,
    DeviceResetEnabled,
    ScreenshotEnabled,
    MobileNetworkSettingsEnabled,
    UsbMassStorageEnabled Q_DECL_DEPRECATED,
    UsbDeveloperModeEnabled,
    UsbMtpEnabled,
    UsbHostEnabled Q_DECL_DEPRECATED,
    UsbConnectionSharingEnabled Q_DECL_DEPRECATED,
    UsbDiagnosticModeEnabled Q_DECL_DEPRECATED,
    UsbAdbEnabled Q_DECL_DEPRECATED,
    DateTimeSettingsEnabled,
    MicrophoneEnabled,
    FlightModeToggleEnabled,
    NetworkProxySettingsEnabled,
    NetworkDataCounterSettingsEnabled,
    CallStatisticsSettingsEnabled,
    CellularTechnologySettingsEnabled,
    MobileDataAccessPointSettingsEnabled,
    VpnConnectionSettingsEnabled,
    VpnConfigurationSettingsEnabled,
    BrowserEnabled,
    AccountCreationEnabled,
    BluetoothToggleEnabled,
    SdMountEnabled,
    UsbMountEnabled,
    GlobalServicesSettingsEnabled,
    VoiceCallEnabled,
    SMSEnabled,
    SimPinningSettingsEnabled,
    SimSlotsSettingsEnabled,
    DevelSuEnabled,
};

#ifdef  __cplusplus
}
}
#endif

#endif
